==> DecisionTree-0.1.4.tar.gz: DecisionTree/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Decision Trees';
$lang['postinstall'] = 'Decision Tree Module has been installed.';
$lang['postuninstall'] = 'Decision Tree module has been uninstalled.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['submit'] = 'Save';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';

$lang['title_listing'] = 'Decision Trees';
$lang['title_import'] = 'Import';
$lang['title_tree_alias']='Tree Alias';
$lang['title_tree_description']='Description';
$lang['title_tree_file']='XML Source File';
$lang['summary_imported']='Successfully imported file.';
$lang['parse_failed']='Failed to parse the XML file.';
$lang['parse_decision_name']='Cannot parse decision name attribute in line %s';
$lang['parse_outcome_name']='Cannot parse outcome name attribute in line %s';
$lang['db_failed']='DB Query failed.';
$lang['parse_outcome_results']='Cannot parse outcome results attribute in line %s';
$lang['title_no_trees']='No Decision Trees defined.';
$lang['title_tree']='Decision Tree';
$lang['title_usage']='Usage';
$lang['title_action']='Action';
$lang['help_tree']='Alias of Decision Tree to include';
$lang['title_delete']='Delete Tree';
$lang['title_template']='Edit Template';
$lang['sure_delete']='Are you sure you want to delete decision tree "%s"?';
$lang['deleted']='Decision tree deleted.';
$lang['template_updated']='Template updated.';
$lang['title_prompt']='Please select one';
$lang['title_overwrite']='Overwrite existing tree of same alias?';

$lang['moddescription'] = 'Build interactive suggestion system / decision trees.';

$lang['changelog'] = '<ul>
<li>Version 0.1.4 March 2009. Support overwriting old trees on import.</li>
<li>Version 0.1.3 March 2009. Split out Javascript from template.</li>
<li>Version 0.1.2 March 2009. Added ability to change the prompt on a per-decision-set basis.</li>
<li>Version 0.1.1 March 2009. Refactoring, revisions.</li>
<li>Version 0.1 26 February 2009. Initial Private Release.</li></ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>Use this module to create decision-trees, for doing interactive recommendations, pricing, configuration, etc.</p>
<h3>How Do I Use It</h3>
<p>Create a Decision Tree using any XML editor. Decision tree format is loosely following a standard which can be found floating around on the internet (ain\'t that a typical programmer statement? No reference, no exact standard, imprecise compliance. Crimminey!). Rather than reproduce an example here in the instructions, take a look at the example in the modules/DecisionTree/sample directory.</p>
<p>More documentation on the file format will be added if I get enough requests.</p>
<p>Import your XML file into the DecisionTree admin, give it an alias, and, if you want, a description. Then place the displayed tag in your content page. That is pretty much al you need to do.</p>
<h3>Known Bugs</h3>
<ul>
<li>In this version, only one decision tree can be included in a given page.</li>
<li>Trees need to be balanced at any given depth; e.g., you can\'t have results and decisions on the same level</li>
</ul>
<p>These bugs are fixable. Let me know if they are important to you.</p>
<h3>Sponsorship</h3>
<p>Author gratefully acknowledge the sponsorship of "digi3" for this module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/decisiontree/">Decision Tree Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2009, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>

==> DecisionTree-0.2.2.tar.gz: DecisionTree/lang/en_US.php <==
<?php
$lang['expand_all'] = 'Expand All';
$lang['collapse_all'] = 'Collapse All';
$lang['new_top_node'] = 'Create New Toplevel Node';
$lang['create_new_tree'] = 'Create New Tree';
$lang['info_no_tree'] = 'There are no decisions for this tree.  If adding a new tree you must submit a name and a description first.  Then edit the tree';
$lang['allow_decision_wysiwyg'] = 'Allow Wysiwyg on the Decision Field';
$lang['move_up'] = 'Move Up';
$lang['move_down'] = 'Move Down';
$lang['prompt'] = 'Prompt';
$lang['error_decision_required'] = 'The Decision parameter is a required field.  Please supply a value';
$lang['error_deleteparent'] = 'You cannot delete an item with children';
$lang['error_move'] = 'Problem moving node (invalid parameters?)';
$lang['title_add_node'] = 'Add Node';
$lang['title_edit_node'] = 'Edit Node';
$lang['alternate'] = 'Alternate';
$lang['suggestion'] = 'Suggestion';
$lang['parent'] = 'Parent';
$lang['decision'] = 'Decision';
$lang['result'] = 'Result';
$lang['none'] = 'None';
$lang['title_export'] = 'Export to XML';
$lang['order'] = 'Order';
$lang['edit_node'] = 'Edit this Node';
$lang['delete_node'] = 'Delete this Node';
$lang['option'] = 'Option';
$lang['result'] = 'Result';
$lang['description'] = 'Description';
$lang['type'] = 'Type';
$lang['cancel'] = 'Cancel';
$lang['edit'] = 'Edit';
$lang['friendlyname'] = 'Decision Trees';
$lang['postinstall'] = 'Decision Tree Module has been installed.';
$lang['postuninstall'] = 'Decision Tree module has been uninstalled.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['submit'] = 'Save';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['missingparam'] = 'A required parameter was not provided to the action';
$lang['edit_tree'] = 'Edit Decision Tree';

$lang['title_listing'] = 'Decision Trees';
$lang['title_import'] = 'Import';
$lang['title_tree_alias']='Tree Alias';
$lang['title_tree_description']='Tree Description';
$lang['title_tree_file']='XML Source File';
$lang['summary_imported']='Successfully imported file.';
$lang['parse_failed']='Failed to parse the XML file.';
$lang['parse_decision_name']='Cannot parse decision name attribute in line %s';
$lang['parse_outcome_name']='Cannot parse outcome name attribute in line %s';
$lang['db_failed']='DB Query failed.';
$lang['parse_outcome_results']='Cannot parse outcome results attribute in line %s';
$lang['title_no_trees']='No Decision Trees defined.';
$lang['title_tree']='Decision Tree';
$lang['title_usage']='Usage';
$lang['title_action']='Action';
$lang['help_tree']='Alias of Decision Tree to include';
$lang['title_delete']='Delete Tree';
$lang['title_template']='Edit Template';
$lang['sure_delete']='Are you sure you want to delete decision tree "%s"?';
$lang['deleted']='Decision tree deleted.';
$lang['template_updated']='Template updated.';
$lang['title_prompt']='Please select one';
$lang['title_overwrite']='Overwrite existing tree of same alias?';

$lang['moddescription'] = 'Build interactive suggestion system / decision trees.';

$lang['changelog'] = '<ul>
<li>Version 0.1.5 Jan 2011. Fix/support for single-option trees.</li>
<li>Version 0.1.4 March 2009. Support overwriting old trees on import.</li>
<li>Version 0.1.3 March 2009. Split out Javascript from template.</li>
<li>Version 0.1.2 March 2009. Added ability to change the prompt on a per-decision-set basis.</li>
<li>Version 0.1.1 March 2009. Refactoring, revisions.</li>
<li>Version 0.1 26 February 2009. Initial Private Release.</li></ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>Use this module to create decision-trees, for doing interactive recommendations, pricing, configuration, etc.</p>
<h3>How Do I Use It</h3>
<p>Create a Decision Tree using any XML editor. Decision tree format is loosely following a standard which can be found floating around on the internet (ain\'t that a typical programmer statement? No reference, no exact standard, imprecise compliance. Crimminey!). Rather than reproduce an example here in the instructions, take a look at the example in the modules/DecisionTree/sample directory.</p>
<p>More documentation on the file format will be added if I get enough requests.</p>
<p>Import your XML file into the DecisionTree admin, give it an alias, and, if you want, a description. Then place the displayed tag in your content page. That is pretty much al you need to do.</p>
<h3>Known Bugs</h3>
<ul>
<li>In this version, only one decision tree can be included in a given page.</li>
<li>Trees need to be balanced at any given depth; e.g., you can\'t have results and decisions on the same level</li>
</ul>
<p>These bugs are fixable. Let me know if they are important to you.</p>
<h3>Sponsorship</h3>
<p>Author gratefully acknowledge the sponsorship of "digi3" for this module.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/decisiontree/">Decision Tree Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2009, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&lt;sjg@cmsmodules.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>
